@@ -290,7 +290,7 @@ class WorkflowMultiBranchDefaults(WorkflowMultiBranch):
 
 
 def bitbucket_scm(xml_parent, data):
-    """Configure BitBucket scm
+    r"""Configure BitBucket scm
 
     Requires the :jenkins-wiki:`Bitbucket Branch Source Plugin
     <Bitbucket+Branch+Source+Plugin>`.
@@ -325,6 +325,10 @@ def bitbucket_scm(xml_parent, data):
         discovered initially or a change from the previous revision has been
         detected. (optional)
         Refer to :func:`~build_strategies <build_strategies>`.
+    :arg dict property-strategies: Provides control over how to build a branch
+        (like to disable SCM triggering or to override the pipeline durability)
+        (optional)
+        Refer to :func:`~property_strategies <property_strategies>`.
     :arg bool local-branch: Check out to matching local branch
         If given, checkout the revision to build as HEAD on this branch.
         If selected, then the branch name is computed from the remote branch
@@ -485,6 +489,9 @@ def bitbucket_scm(xml_parent, data):
         helpers.convert_mapping_to_xml(
             dbr, data, dbr_mapping, fail_required=True)
 
+    if data.get('property-strategies', None):
+        property_strategies(xml_parent, data)
+
     if data.get('build-strategies', None):
         build_strategies(xml_parent, data)
 
@@ -564,6 +571,10 @@ def gerrit_scm(xml_parent, data):
         discovered initially or a change from the previous revision has been
         detected. (optional)
         Refer to :func:`~build_strategies <build_strategies>`.
+    :arg dict property-strategies: Provides control over how to build a branch
+        (like to disable SCM triggering or to override the pipeline durability)
+        (optional)
+        Refer to :func:`~property_strategies <property_strategies>`.
 
     Minimal Example:
 
@@ -621,12 +632,15 @@ def gerrit_scm(xml_parent, data):
             '.RefSpecsSCMSourceTrait_-RefSpecTemplate'))
         XML.SubElement(e, 'value').text = x
 
+    if data.get('property-strategies', None):
+        property_strategies(xml_parent, data)
+
     if data.get('build-strategies', None):
         build_strategies(xml_parent, data)
 
 
 def git_scm(xml_parent, data):
-    """Configure Git SCM
+    r"""Configure Git SCM
 
     Requires the :jenkins-wiki:`Git Plugin <Git+Plugin>`.
 
@@ -648,6 +662,10 @@ def git_scm(xml_parent, data):
         discovered initially or a change from the previous revision has been
         detected. (optional)
         Refer to :func:`~build_strategies <build_strategies>`.
+    :arg dict property-strategies: Provides control over how to build a branch
+        (like to disable SCM triggering or to override the pipeline durability)
+        (optional)
+        Refer to :func:`~property_strategies <property_strategies>`.
 
     :extensions:
 
@@ -722,6 +740,9 @@ def git_scm(xml_parent, data):
             'jenkins.scm.impl.trait.RegexSCMHeadFilterTrait')
         XML.SubElement(rshf, 'regex').text = data.get('head-filter-regex')
 
+    if data.get('property-strategies', None):
+        property_strategies(xml_parent, data)
+
     if data.get('build-strategies', None):
         build_strategies(xml_parent, data)
 
@@ -738,14 +759,18 @@ def git_scm(xml_parent, data):
 
 
 def github_scm(xml_parent, data):
-    """Configure GitHub SCM
+    r"""Configure GitHub SCM
 
     Requires the :jenkins-wiki:`GitHub Branch Source Plugin
     <GitHub+Branch+Source+Plugin>`.
 
     :arg str api-uri: The GitHub API uri for hosted / on-site GitHub. Must
         first be configured in Global Configuration. (default GitHub)
-    :arg bool ssh-checkout: Checkout over SSH. (default false)
+    :arg bool ssh-checkout: Checkout over SSH.
+
+        * **credentials** ('str'): Credentials to use for
+            checkout of the repo over ssh.
+
     :arg str credentials-id: Credentials used to scan branches and pull
         requests, check out sources and mark commit statuses. (optional)
     :arg str repo-owner: Specify the name of the GitHub Organization or
@@ -770,6 +795,10 @@ def github_scm(xml_parent, data):
         discovered initially or a change from the previous revision has been
         detected. (optional)
         Refer to :func:`~build_strategies <build_strategies>`.
+    :arg dict property-strategies: Provides control over how to build a branch
+        (like to disable SCM triggering or to override the pipeline durability)
+        (optional)
+        Refer to :func:`~property_strategies <property_strategies>`.
 
     :extensions:
 
@@ -781,6 +810,10 @@ def github_scm(xml_parent, data):
         * **depth** (`int`) - Set shallow clone depth (default 1)
         * **do-not-fetch-tags** (`bool`) - Perform a clone without tags
             (default false)
+        * **disable-pr-notifications** (`bool`) - Disable default github status
+            notifications on pull requests (default false) (Requires the
+            :jenkins-plugins:`GitHub Branch Source Plugin
+            <disable-github-multibranch-status>`.)
         * **submodule** (`dict`)
             * **disable** (`bool`) - By disabling support for submodules you
               can still keep using basic git plugin functionality and just have
@@ -852,12 +885,21 @@ def github_scm(xml_parent, data):
         helpers.convert_mapping_to_xml(
             bd, data, bd_mapping, fail_required=True)
 
-    if data.get('ssh-checkout', False):
-        XML.SubElement(
+    if data.get('ssh-checkout', None):
+        cossh = XML.SubElement(
             traits, ''.join([
                 github_path_dscore, '.SSHCheckoutTrait'
             ])
         )
+        if not isinstance(data.get('ssh-checkout'), bool):
+            cossh_credentials = [
+                ('credentials', 'credentialsId', ''),
+            ]
+            helpers.convert_mapping_to_xml(
+                cossh,
+                data.get('ssh-checkout'),
+                cossh_credentials,
+                fail_required=True)
 
     if data.get('discover-tags', False):
         XML.SubElement(
@@ -926,6 +968,9 @@ def github_scm(xml_parent, data):
     helpers.convert_mapping_to_xml(
         dpro, data, dpro_mapping, fail_required=True)
 
+    if data.get('property-strategies', None):
+        property_strategies(xml_parent, data)
+
     if data.get('build-strategies', None):
         build_strategies(xml_parent, data)
 
@@ -940,6 +985,18 @@ def github_scm(xml_parent, data):
     # - use-author
     git_extensions(traits, data)
 
+    # github-only extensions
+    disable_github_status_path_dscore = (
+        'com.adobe.jenkins.disable__github__multibranch__status')
+    if data.get('disable-pr-notifications', False):
+        XML.SubElement(
+            traits, ''.join([
+                disable_github_status_path_dscore, '.DisableStatusUpdateTrait'
+            ]), {
+                'plugin': 'disable-github-multibranch-status'
+            }
+        )
+
 
 def build_strategies(xml_parent, data):
     """Configure Basic Branch Build Strategies.
@@ -1077,3 +1134,62 @@ def build_strategies(xml_parent, data):
                         nb['wildcards-name'],
                         wildcards_name_mapping,
                         fail_required=False)
+
+
+def property_strategies(xml_parent, data):
+    """Configure Basic Branch Property Strategies.
+
+    Requires the :jenkins-wiki:`Branch API Plugin <Branch+API+Plugin>`.
+
+    :arg dict property-strategies: Definition of property strategies.
+
+        * **all-branches** (list): A list of property strategy definitions
+            for use with all branches.
+
+            * **suppress-scm-triggering** (bool): Suppresses automatic SCM
+                triggering (optional)
+            * **pipeline-branch-durability-override** (str): Set a custom
+                branch speed/durability level. Valid values:
+                performance-optimized, survivable-nonatomic, or
+                max-survivability (optional) Requires the :jenkins-wiki:
+                `Pipeline Multibranch Plugin <Pipeline+Multibranch+Plugin>`
+    """
+
+    # Valid options for the pipeline branch durability override.
+    pbdo_map = collections.OrderedDict([
+        ("max-survivability", "MAX_SURVIVABILITY"),
+        ("performance-optimized", "PERFORMANCE_OPTIMIZED"),
+        ("survivable-nonatomic", "SURVIVABLE_NONATOMIC"),
+    ])
+    basic_property_strategies = 'jenkins.branch'
+    workflow_multibranch = 'org.jenkinsci.plugins.workflow.multibranch'
+    dbps = XML.SubElement(xml_parent, 'strategy', {
+        'class': ''.join([basic_property_strategies,
+                          '.DefaultBranchPropertyStrategy'])})
+    prop_strats = data.get('property-strategies', None)
+
+    if prop_strats:
+        props_elem = XML.SubElement(dbps, 'properties', {
+            'class': 'java.util.Arrays$ArrayList'})
+        props_elem = XML.SubElement(props_elem, 'a', {
+            'class': ''.join([
+                basic_property_strategies, '.BranchProperty-array'])})
+
+        for dbs_list in prop_strats.get('all-branches', None):
+
+            if dbs_list.get('suppress-scm-triggering', False):
+                XML.SubElement(props_elem, ''.join([
+                    basic_property_strategies, '.NoTriggerBranchProperty']))
+
+            pbdo_val = dbs_list.get(
+                'pipeline-branch-durability-override', None)
+            if pbdo_val:
+                if not pbdo_map.get(pbdo_val):
+                    raise InvalidAttributeError(
+                        'pipeline-branch-durability-override',
+                        pbdo_val,
+                        pbdo_map.keys())
+                pbdo_elem = XML.SubElement(props_elem, ''.join([
+                    workflow_multibranch, '.DurabilityHintBranchProperty']), {
+                        'plugin': 'workflow-multibranch'})
+                XML.SubElement(pbdo_elem, 'hint').text = pbdo_map.get(pbdo_val)
