@@ -206,6 +206,43 @@ def gitlab(registry, xml_parent, data):
     helpers.convert_mapping_to_xml(gitlab, data, mapping, fail_required=True)
 
 
+def gitlab_logo(registry, xml_parent, data):
+    """yaml: gitlab-logo
+    Configures the GitLab-Logo Plugin.
+    Requires the Jenkins :jenkins-wiki:`GitLab Logo Plugin
+    <GitLab+Logo+Plugin>`.
+
+    :arg str repository-name: the GitLab repository name (required)
+
+    Example:
+
+    .. literalinclude:: /../../tests/properties/fixtures/gitlab-logo.yaml
+       :language: yaml
+    """
+    logo = XML.SubElement(xml_parent,
+                          'org.jenkinsci.plugins.gitlablogo.'
+                          'GitlabLogoProperty')
+    mapping = [
+        ('repository-name', 'repositoryName', None)
+    ]
+    helpers.convert_mapping_to_xml(logo, data, mapping, fail_required=True)
+
+
+def disk_usage(registry, xml_parent, data):
+    """yaml: disk-usage
+    Enables the Disk Usage Plugin.
+    Requires the Jenkins :jenkins-wiki:`Disk Usage Plugin <Disk+Usage+Plugin>`.
+
+    Example:
+
+    .. literalinclude:: /../../tests/properties/fixtures/disk-usage.yaml
+       :language: yaml
+    """
+    XML.SubElement(xml_parent,
+                   'hudson.plugins.disk__usage.'
+                   'DiskUsageProperty')
+
+
 def least_load(registry, xml_parent, data):
     """yaml: least-load
     Enables the Least Load Plugin.
@@ -613,7 +650,7 @@ def build_blocker(registry, xml_parent, data):
     mapping = [
         ('use-build-blocker', 'useBuildBlocker', True),
         ('', 'blockingJobs', jobs),
-        ('blocking-level', 'blockLevel', 'GLOBAL', block_level_types),
+        ('block-level', 'blockLevel', 'GLOBAL', block_level_types),
         ('queue-scanning', 'scanQueueFor', 'DISABLED', queue_scan_types),
     ]
     helpers.convert_mapping_to_xml(blocker, data, mapping, fail_required=True)
@@ -1100,6 +1137,9 @@ def docker_container(registry, xml_parent, data):
     """yaml: docker-container
     Requires the Jenkins: :jenkins-wiki:`Docker Plugin<Docker+Plugin>`.
 
+    :arg str docker-registry-url: URL of the Docker registry. (default '')
+    :arg str credentials-id: Credentials Id for the Docker registey.
+        (default '')
     :arg bool commit-on-success: When a job completes, the docker slave
         instance is committed with repository based on the job name and build
         number as tag. (default false)
@@ -1125,6 +1165,14 @@ def docker_container(registry, xml_parent, data):
     xml_docker = XML.SubElement(
         xml_parent, 'com.nirima.jenkins.plugins.docker.DockerJobProperty')
 
+    registry = XML.SubElement(xml_docker, 'registry')
+    registry.set('plugin', 'docker-commons')
+    registry_mapping = [
+        ('docker-registry-url', 'url', ''),
+        ('credentials-id', 'credentialsId', ''),
+    ]
+    helpers.convert_mapping_to_xml(
+        registry, data, registry_mapping, fail_required=False)
     mapping = [
         ('commit-on-success', 'tagOnCompletion', False),
         ('additional-tag', 'additionalTag', ''),
